==> linux-command-1.8.2.tgz: package/command/info.md <==
info
===

Linux下info格式的帮助指令

## 补充说明

**info命令** 是Linux下info格式的帮助指令。

就内容来说，info页面比man page编写得要更好、更容易理解，也更友好，但man page使用起来确实要更容易得多。一个man page只有一页，而info页面几乎总是将它们的内容组织成多个区段（称为节点），每个区段也可能包含子区段（称为子节点）。理解这个命令的窍门就是不仅要学习如何在单独的Info页面中浏览导航，还要学习如何在节点和子节点之间切换。可能刚开始会一时很难在info页面的节点之间移动和找到你要的东西，真是具有讽刺意味：原本以为对于新手来说，某个东西比man命令会更好些，但实际上学习和使用起来更困难。

###  语法

```shell
info(选项)(参数)
```

###  选项

```shell
-d：添加包含info格式帮助文档的目录；
-f：指定要读取的info格式的帮助文档；
-n：指定首先访问的info帮助文件的节点；
-o：输出被选择的节点内容到指定文件。
```

###  参数

帮助主题：指定需要获得帮助的主题，可以是指令、函数以及配置文件。

###  实例

在info后面输入命令的名称就可以查看该命令的info帮助文档了：

```shell
info info
```

面介绍一下它的几个常用快捷键。

```shell
 **?键：** 它就会显示info的常用快捷键。
 **N键：** 显示（相对于本节点的）下一节点的文档内容。
 **P键：** 显示（相对于本节点的）前一节点的文档内容。
 **U键：** 进入当前命令所在的主题。
 **M键：** 敲M键后输入命令的名称就可以查看该命令的帮助文档了。
 **G键：** 敲G键后输入主题名称，进入该主题。
 **L键：** 回到上一个访问的页面。
 **SPACE键：** 向前滚动一页。
 **BACKUP或DEL键：** 向后滚动一页。
 **Q：** 退出info。
```

**命令** 

```shell
 **？**      显示帮助窗口

在帮助窗口中：
 **Ctrl-x 0**           关闭帮助窗口
 **Ctrl-x Ctrl-c**     关闭整个 Info

 **q**       退出 info
 **n**       打开与本 Node 关联的下一个 Node
 **p**       打开与本 Node 关联的前一个 Node
 **u**       打开与本 Node 关联的上一个 Node
 **l**       回到上一次访问的 Node
 **m或g**    选择一个菜单项（Node 的名字）
       输入指定菜单的名字后按回车，打开指定菜单项关联的 Node
 **空格键**  下一页（PageDown 也可以，下一页从当前页的最后两行开始算起）
       下一个 Node （若当前页在 Node 文档的末尾）
 **Del 键**  上一页（PageUp 也可以，上一页从当前页的开始两行开始算起）
       上一个 Node （若当前页 Node 文档的开始）

 **b 或 t 或 Home**    文档的开始（b 是 begining 的意思）
 **e 或 End**          文档的末尾（b 是 ending 的意思）
 **Ctrl-l**     刷新当前页，若当前文档显示情况有问题时
 **Ctrl-g**     取消所键入的指令
```


<!-- Linux命令行搜索引擎：https://jaywcjlove.github.io/linux-command/ -->

==> linux-command-1.19.0.tgz: package/command/info.md <==
info
===

Linux下info格式的帮助指令

## 补充说明

**info命令** 是Linux下info格式的帮助指令。

就内容来说，info页面比man page编写得要更好、更容易理解，也更友好，但man page使用起来确实要更容易得多。一个man page只有一页，而info页面几乎总是将它们的内容组织成多个区段（称为节点），每个区段也可能包含子区段（称为子节点）。理解这个命令的窍门就是不仅要学习如何在单独的Info页面中浏览导航，还要学习如何在节点和子节点之间切换。可能刚开始会一时很难在info页面的节点之间移动和找到你要的东西，真是具有讽刺意味：原本以为对于新手来说，某个东西比man命令会更好些，但实际上学习和使用起来更困难。

###  语法

```shell
info(选项)(参数)
```

###  选项

```shell
-d：添加包含info格式帮助文档的目录；
-f：指定要读取的info格式的帮助文档；
-n：指定首先访问的info帮助文件的节点；
-o：输出被选择的节点内容到指定文件。
```

###  参数

帮助主题：指定需要获得帮助的主题，可以是指令、函数以及配置文件。

###  实例

在info后面输入命令的名称就可以查看该命令的info帮助文档了：

```shell
info info
```

面介绍一下它的几个常用快捷键。

```shell
 **?键：** 它就会显示info的常用快捷键。
 **N键：** 显示（相对于本节点的）下一节点的文档内容。
 **P键：** 显示（相对于本节点的）前一节点的文档内容。
 **U键：** 进入当前命令所在的主题。
 **M键：** 敲M键后输入命令的名称就可以查看该命令的帮助文档了。
 **G键：** 敲G键后输入主题名称，进入该主题。
 **L键：** 回到上一个访问的页面。
 **SPACE键：** 向前滚动一页。
 **BACKUP或DEL键：** 向后滚动一页。
 **Q：** 退出info。
```

**命令** 

```shell
 **？**      显示帮助窗口

在帮助窗口中：
 **Ctrl-x 0**           关闭帮助窗口
 **Ctrl-x Ctrl-c**     关闭整个 Info

 **q**       退出 info
 **n**       打开与本 Node 关联的下一个 Node
 **p**       打开与本 Node 关联的前一个 Node
 **u**       打开与本 Node 关联的上一个 Node
 **l**       回到上一次访问的 Node
 **m或g**    选择一个菜单项（Node 的名字）
       输入指定菜单的名字后按回车，打开指定菜单项关联的 Node
 **空格键**  下一页（PageDown 也可以，下一页从当前页的最后两行开始算起）
       下一个 Node （若当前页在 Node 文档的末尾）
 **Del 键**  上一页（PageUp 也可以，上一页从当前页的开始两行开始算起）
       上一个 Node （若当前页 Node 文档的开始）

 **b 或 t 或 Home**    文档的开始（b 是 beginning 的意思）
 **e 或 End**          文档的末尾（b 是 ending 的意思）
 **Ctrl-l**     刷新当前页，若当前文档显示情况有问题时
 **Ctrl-g**     取消所键入的指令
```
